==> generator-webpublico-0.5.5.tgz: package/generators/app/templates/webpublico/src/test/java/br/com/webpublico/entities/_EntityTest.java <==
package br.com.webpublico.<%=modulo%>.entities;

import br.com.webpublico.UnitTestContext;
import br.com.webpublico.comum.entities.AbstractSuperEntidadeTest;
import br.com.webpublico.comum.exceptions.CampoObrigatorioException;
import br.com.webpublico.comum.exceptions.OperacaoNaoPermitidaException;
import br.com.webpublico.comum.exceptions.ValorCampoInvalidoException;

import org.junit.Test;
import org.junit.runner.RunWith;
import org.springframework.test.context.ContextConfiguration;
import org.springframework.test.context.junit4.SpringJUnit4ClassRunner;

import static br.com.webpublico.comum.utils.TestUtil.randomValue;
import static br.com.webpublico.comum.utils.TestUtil.getConteudoMaiorQueExtraLonga;

@RunWith(SpringJUnit4ClassRunner.class)
@ContextConfiguration(classes = {UnitTestContext.class})
public class <%=classe%>Test extends AbstractSuperEntidadeTest<<%=classe%>> {

    @Override
    protected <%=classe%> buildSut() {
        <%=classe%> sut = new <%=classe%>();<%for(fieldId in fields) { if(fields[fieldId].annotations.obrigatorio) {%>
        sut.set<%=fields[fieldId].capitalizedFieldName%>((<%=fields[fieldId].fieldType.type%>)randomValue(<%=fields[fieldId].fieldType.type%>.class, <%=fields[fieldId].fieldType.size ? fields[fieldId].fieldType.size : 'null'%>));<%}}%>
        return sut;
    }<%for(fieldId in fields) {%><%if(fields[fieldId].annotations.obrigatorio) {%>

    @Test(expected = CampoObrigatorioException.class)
    public void realizarValidacoes_<%=fields[fieldId].fieldName%>Null_jogaCampoObrigatorioException() throws OperacaoNaoPermitidaException {
        sut.set<%=fields[fieldId].capitalizedFieldName%>(null);
        sut.realizarValidacoes();
    }<%if(fields[fieldId].fieldType.isString) {%>

    @Test(expected = CampoObrigatorioException.class)
    public void realizarValidacoes_<%=fields[fieldId].fieldName%>StringVazia_jogaCampoObrigatorioException() throws OperacaoNaoPermitidaException {
        sut.set<%=fields[fieldId].capitalizedFieldName%>("");
        sut.realizarValidacoes();
    }

    @Test(expected = CampoObrigatorioException.class)
    public void realizarValidacoes_<%=fields[fieldId].fieldName%>DezEspacos_jogaCampoObrigatorioException() throws OperacaoNaoPermitidaException {
        sut.set<%=fields[fieldId].capitalizedFieldName%>("          ");
        sut.realizarValidacoes();
    }<%}}%><%if(fields[fieldId].fieldType.size && fields[fieldId].fieldType.isString) {%>

    @Test(expected = ValorCampoInvalidoException.class)
    public void realizarValidacoes_<%=fields[fieldId].fieldName%>MaiorQueExtraLonga_jogaValorCampoInvalidoException() throws OperacaoNaoPermitidaException {
        sut.set<%=fields[fieldId].capitalizedFieldName%>(getConteudoMaiorQueExtraLonga());
        sut.realizarValidacoes();
    }
    <%}%><%if (fields[fieldId].fieldType.isString) {%>

    @Test
    public void realizarValidacoes_<%=fields[fieldId].fieldName%>ComValorTeste_naoJogaException() throws OperacaoNaoPermitidaException {
        sut.set<%=fields[fieldId].capitalizedFieldName%>("Teste");
        sut.realizarValidacoes();
    }<%}}%>
}

==> generator-webpublico-0.7.1.tgz: package/generators/app/templates/webpublico/src/test/java/br/com/webpublico/entities/_EntityTest.java <==
package br.com.webpublico.<%=modulo%>.entities;

import br.com.webpublico.UnitTestContext;
import br.com.webpublico.comum.entities.AbstractSuperEntidadeTest;
import br.com.webpublico.comum.exceptions.CampoObrigatorioException;
import br.com.webpublico.comum.exceptions.OperacaoNaoPermitidaException;
import br.com.webpublico.comum.exceptions.ValorCampoInvalidoException;

import org.junit.Test;
import org.junit.runner.RunWith;
import org.springframework.test.context.ContextConfiguration;
import org.springframework.test.context.junit4.SpringJUnit4ClassRunner;

import static br.com.webpublico.comum.utils.TestUtil.randomValue;
import static br.com.webpublico.comum.utils.TestUtil.getConteudoMaiorQueExtraLonga;

@RunWith(SpringJUnit4ClassRunner.class)
@ContextConfiguration(classes = {UnitTestContext.class})
public class <%=classe%>Test extends AbstractSuperEntidadeTest<<%=classe%>> {

    public static <%=classe%> entidadeValida() {
        <%=classe%> retorno = new <%=classe%>();<%for(fieldId in fields) { if(fields[fieldId].annotations.obrigatorio) {%>
        retorno.set<%=fields[fieldId].capitalizedFieldName%>((<%=fields[fieldId].fieldType.type%>)randomValue(<%=fields[fieldId].fieldType.type%>.class, <%=fields[fieldId].fieldType.size ? fields[fieldId].fieldType.size : 'null'%>));<%}}%>
        return retorno;
    }

    @Override
    protected <%=classe%> buildSut() {
        return entidadeValida();
    }<%for(fieldId in fields) {%><%if(fields[fieldId].annotations.obrigatorio) {%>

    @Test(expected = CampoObrigatorioException.class)
    public void realizarValidacoes_<%=fields[fieldId].fieldName%>Null_jogaCampoObrigatorioException() throws OperacaoNaoPermitidaException {
        sut.set<%=fields[fieldId].capitalizedFieldName%>(null);
        sut.realizarValidacoes();
    }<%if(fields[fieldId].fieldType.isString) {%>

    @Test(expected = CampoObrigatorioException.class)
    public void realizarValidacoes_<%=fields[fieldId].fieldName%>StringVazia_jogaCampoObrigatorioException() throws OperacaoNaoPermitidaException {
        sut.set<%=fields[fieldId].capitalizedFieldName%>("");
        sut.realizarValidacoes();
    }

    @Test(expected = CampoObrigatorioException.class)
    public void realizarValidacoes_<%=fields[fieldId].fieldName%>DezEspacos_jogaCampoObrigatorioException() throws OperacaoNaoPermitidaException {
        sut.set<%=fields[fieldId].capitalizedFieldName%>("          ");
        sut.realizarValidacoes();
    }<%}}%><%if(fields[fieldId].fieldType.size && fields[fieldId].fieldType.isString) {%>

    @Test(expected = ValorCampoInvalidoException.class)
    public void realizarValidacoes_<%=fields[fieldId].fieldName%>MaiorQueExtraLonga_jogaValorCampoInvalidoException() throws OperacaoNaoPermitidaException {
        sut.set<%=fields[fieldId].capitalizedFieldName%>(getConteudoMaiorQueExtraLonga());
        sut.realizarValidacoes();
    }
    <%}%><%if (fields[fieldId].fieldType.isString) {%>

    @Test
    public void realizarValidacoes_<%=fields[fieldId].fieldName%>ComValorTeste_naoJogaException() throws OperacaoNaoPermitidaException {
        sut.set<%=fields[fieldId].capitalizedFieldName%>("Teste");
        sut.realizarValidacoes();
    }<%}}%>
}
